@@ -6,7 +6,7 @@ use warnings;
 use Scalar::Util qw(blessed);
 use Carp qw(croak);
 use vars qw($error $VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
-$VERSION=.009;
+$VERSION=1.011;
 use Scalar::Util qw(looks_like_number);
 use overload
         '""' => \&notation
@@ -226,9 +226,6 @@ Range processing functions :PROCESS
         	range_start_end_fill
         	range_compare
 
-=cut
-
-
 =head2 OO Methods
 
 This section defines the OO interfaces.
@@ -644,10 +641,37 @@ sub get_first_cidr () {
 
 }
 
+=item * if($obj->is_cidr) { do something }
+
+This function can be used to check if a range represents a single cidr.
+
+=cut
+
+sub is_cidr () {
+	my ($s)=@_;
+	my ($range,$cidr,$next)=$s->get_first_cidr;
+	my $is_cidr=defined($next) ? 0 : 1;
+	$is_cidr
+}
+
+=item * if($obj->is_range) { do something }
+
+This function can be used to check if a ranges contains multiple cidrs.
+
+=cut
+
+sub is_range () {
+	my ($s)=@_;
+	my ($range,$cidr,$next)=$s->get_first_cidr;
+	my $is_range=defined($next) ? 1 : 0;
+	$is_range
+}
+
 ###########################################
 #
 
 =item * my $sub=$obj->enumerate(1-32);
+
 =item * my $sub=$obj->enumerate;
 
 Returns an anonymous subroutine that can be used to iterate through the entire range.  The iterator can be used to safely walk any range even 0/0.  Each iteration of $sub returns a new Net::IPRangeCompare object or undef on completion.
@@ -713,7 +737,6 @@ sub enumerate {
 
 =back
 
-
 =head2 Helper functions
 
 =over 4
@@ -799,7 +822,7 @@ objects:  Returns undef if no overlapping range is found.
 
 sub get_common_range ($) {
 	my ($ranges)=@_;
-	croak 'empty range refrence' if $#$ranges==-1;
+	croak 'empty range reference' if $#$ranges==-1;
 	my ($first_int)=sort sort_largest_first_int_first @$ranges;
 	my ($last_int)=sort sort_smallest_last_int_first @$ranges;
 
@@ -814,12 +837,6 @@ sub get_common_range ($) {
 
 =back
 
-=cut
-
-###########################################
-#
-# Sort mechanism for all internal code.
-
 =head2 Sort Functions
 
 	sort_largest_last_int_first
@@ -846,7 +863,6 @@ sub get_common_range ($) {
 
 =cut
 
-
 sub sort_ranges ($$) {
 	my ($range_a,$range_b)=@_;
 
@@ -968,7 +984,7 @@ This section covers how to use the list and list of lists processing functions t
 
 =item * my $list_ref=consolidate_ranges(\@list_of_netiprangeobjects);
 
-Given a list reference of Net::IPRangeCompare Objects: Returns consolidated list reference to the input ranges.  The list input reference is depleted during the consolidation process.  If you want to keep the original list of ranges, make a copy of the list before passing it to consolidate_ranges.
+Given a list reference of Net::IPRangeCompare Objects: Returns a consolidated list reference representing the input ranges.  The list input reference is depleted during the consolidation process.  If you want to keep the original list of ranges, make a copy of the list before passing it to consolidate_ranges.
 
 Example:
 
@@ -1018,7 +1034,7 @@ sub consolidate_ranges ($) {
 
 =item * my $ranges=fill_missing_ranges(\@consolidated_list);
 
-Given a consolidated list of Net::IPRangeCompare objects, it returns a contiguous list of ranges.  All ranges generated by the fill_missing_ranges are $obj->missing==true and $obj->generated==true.
+Given a consolidated list of Net::IPRangeCompare objects, it returns a contiguous list reference of ranges.  All ranges generated by the fill_missing_ranges are $obj->missing==true and $obj->generated==true.
 
 Example:
 
@@ -1052,9 +1068,9 @@ Notes:
 sub fill_missing_ranges ($) {
 	my ($ranges)=@_;
 	
-	croak 'argument is not an array refrence' unless
+	croak 'argument is not an array reference' unless
 		ref($ranges) and ref($ranges) eq 'ARRAY';
-	croak 'empty list refrence' if $#$ranges==-1;
+	croak 'empty list reference' if $#$ranges==-1;
 	# first we have to consolidate the ranges
 	my $class=blessed $ranges->[0];
 
@@ -1123,9 +1139,9 @@ Notes:
 sub range_start_end_fill ($) {
 	my ($ranges)=@_;
 
-	croak 'argument is not an array refrence' unless
+	croak 'argument is not an array reference' unless
 		ref($ranges) and ref($ranges) eq 'ARRAY';
-	croak 'empty array refrence' if $#$ranges==-1;
+	croak 'empty array reference' if $#$ranges==-1;
 	my $class=blessed $ranges->[0]->[0];
 
 	my ($first_int)=sort sort_smallest_first_int_first
@@ -1423,6 +1439,7 @@ sub get_ranges_by_key ($) {
 #
 
 =item * $obj->compare_ranges;
+
 =item * $obj->compare_ranges(key,key,key);
 
 Used to initialize or re-initialize the compare process. When called with a key or a list of keys: The compare process excludes those columns.
